RENEWS: Markdownize & reverse NEWS object

RENEWSR Documentation

Markdownize & reverse NEWS object

Description

Probably only for me. Each of my maintained packages has a <mypack>.NEWS object (character vector) in a pretty arbitrary format which I might as well markdownize, so that utils::news can process it. Reverse order (previously, most recent came last).) Remove dates.

Usage

RENEWS( pkg, character.only = FALSE)

Arguments

pkg

eg ..debug or debug or "debug" (the latter a string)

character.only

for programmatic use, enforce string format as pkg

Value

Modified <pkg>.NEWS of class cat, so you can check it before manually assiging to eg ..<mypack>$<mypack>.NEWS. Likely to need cleanup with fixr afterwards!

Examples

## Not run: 
if( FALSE && is_very_annoying( CRAN)){ # otherwise CMD CHECK --as-cran tries to run this :/
  RENEWS( mvbutils)
} # if F

## End(Not run)

mvbutils documentation built on May 25, 2026, 5:09 p.m.

Related to RENEWS in mvbutils...