cdprompt: Support routine for cd-organized workspace hierarchy.

cdpromptR Documentation

Support routine for cd-organized workspace hierarchy.

Description

Sets the command-line prompt to the correct value (see cd, and the notes on the option abbreviate.cdprompt); useful if the prompt somehow becomes corrupted. cdprompt never seems necessary in R but has been useful in the S+ manifestations of mvbutils, where system bugs are commoner.

Usage

cdprompt()

Author(s)

Mark Bravington

See Also

cd

Examples

cdprompt()

mvbutils documentation built on May 25, 2026, 5:09 p.m.

Related to cdprompt in mvbutils...