dedoc_namespace: Remove doc attributes when package loads

dedoc_namespaceR Documentation

Remove doc attributes when package loads

Description

Suppose you want to keep plain-text "doc" attributes attached to your function code even in the package source (as opposed to in a private version of the package). You probably don't want them around after the package loads for real, though. In that case, you can stick a call to dedoc_namespace at the end of your .onLoad and everything should be copacetic.

Usage

dedoc_namespace(ns)

Arguments

ns

Name of the package, or its namespace environment.

See Also

write_sourceable_function, pre.install

Examples

## Not run: 
if( FALSE && is_very_annoying( CRAN)){ # otherwise CMD CHECK --as-cran tries to run this :/
  # Put this into your package:
  .onLoad <- function( libname, pkgname){
    # stuff for .onLoad(), or no stuff
    dedoc_package( pkgname)
  }
} # if F

## End(Not run)

mvbutils documentation built on May 25, 2026, 5:09 p.m.