fix.order: Shows functions and scriptlets sorted by date of edit

fix.orderR Documentation

Shows functions and scriptlets sorted by date of edit

Description

fix.order sorts the functions and scriptlets according to the filedates of their backups (in the .Backup.mvb directory). This is very useful for reminding yourself what you were working on recently. It only works if functions and scriptlets have been edited using the fixr system.

Usage

fix.order( env=1)

Arguments

env

a single number, character string, or environment. Numbers and characters are interpreted as search path positions. The environment must be an attached mvb-style task.

Details

Only objects that have a BU*** backup file will appear. Objects that have a BU*** file but have been deleted will not appear.

Value

Character vector of functions and scriptlets sorted by date/time of last modification.

To do

Probably should modify this so it takes an arbitrary task path instead of a search position only. Task doesn't really need to be attached.

Add a pattern argument a la find.funs.

Author(s)

Mark Bravington

See Also

fixr

Examples

## Not run: 
if( FALSE && is_very_annoying( CRAN)){ # otherwise CMD CHECK --as-cran tries to run this :/
  ## Need to create backups and do some function editing first
  fix.order() # functions in .GlobalEnv
  fix.order( "ROOT") # functions in your startup task
} # if F

## End(Not run)

mvbutils documentation built on May 25, 2026, 5:09 p.m.

Related to fix.order in mvbutils...