full.path: Expand relative file path

full.pathR Documentation

Expand relative file path

Description

path is expanded relative to start, with any . being eliminated and any .. being treated as "go back one step". If path doesn't start with a . or .., start is ignored. Might be Windows-specific but probably fairly safe in general. NB that all separators in path and start must be "/".

Usage

full.path(path, start)

Arguments

path

character(1)

start

character(1), defaulting to .


mvbutils documentation built on May 25, 2026, 5:09 p.m.

Related to full.path in mvbutils...