| make.arguments.section | R Documentation |
Don't bother reading about these unless you are sure you need to! These are really intended for expediting documentation of large numbers of "internal" functions in a proto-package, and are called by make.internal.doc. make.usage.section and make.arguments.section form prototype USAGE and ARGUMENTS section for the specified functions. These are ready for pasting into flat-format documentation (and subsequent editing).
make.usage.section( funs=, file=stdout(), env=.GlobalEnv)
make.arguments.section( funs=, file=stdout(), env=.GlobalEnv)
funs |
character vector of function names, defaulting to |
file |
where to put the output ( |
env |
where to look for the functions |
The default funs argument will find all functions not mentioned in flat-format ready-for-doc2Rd documentation. This is useful for documenting a group of "internal" functions.
make.usage.section simply puts the name of each function before its deparsed and concatenated argument list, one function per line.
make.arguments.section puts one argument per line, then a colon, then the name of the function in parentheses. The idea is that something about the argument should be added manually in a text editor.
Character vector containing the doc section (in plain text, not Rd format).
Mark Bravington
flatdoc, pre.install
if( FALSE){
# Can't run this directly, coz internal
# so not exported
ns <- asNamespace( 'mvbutils')
make.usage.section( c( "make.usage.section", "find.funs"),
env=ns)
make.arguments.section( c( "make.usage.section", "find.funs"),
env=ns)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.