mvb.session.env: Session info environment

mvb.session.envR Documentation

Session info environment

Description

Package mvbutils needs a place to stash useful session-level stuff, such as fix.list (see fixr). Since like foreeeever (2001), this has been via a special environment called mvb.session.info which is attached to the search path. However, that's not how yer sposed to do it apparently, so for better security the direct use of mvb.session.info is deprecated in favour of calling the function mvb_session_env() or its dotty synonym. Like the base-R functions globalenv() and baseenv(), an environment is returned.

Future versions of mvbutils package will move the session-info environment into "private" storage within the mvbutils namespace, so that it can only easily be accessed via mvb_session_env() or mvb.session.env().

Usage

mvb_session_env()
mvb.session.env()

Value

Environment where session-level info used by the mvbutils package (and perhaps by other packages, such as debug) is stashed.


mvbutils documentation built on May 25, 2026, 5:09 p.m.