set.presave.hook.mvb: Hook of some kind

set.presave.hook.mvbR Documentation

Hook of some kind

Description

I have forgotten what this function is for, but probably the only reason it's documented is to make sure it's exported... My advice: don't use it! (But it is used by package debug and others.)

Usage

set.presave.hook.mvb( hook, set=TRUE)

Arguments

hook

can't remember

set

boolean...


mvbutils documentation built on May 25, 2026, 5:09 p.m.