task.home: Organizing R workspaces

task.homeR Documentation

Organizing R workspaces

Description

Returns file path to current task, or to a file in that task.

Usage

# Often: task.home()
task.home(fname)

Arguments

fname

file name, a character(1)

Details

Without any arguments, task.home returns the path of the current task. With a filename argument, the filename is interpreted as relative to the current task, and its full (non-relative) path is returned.

task.home is almost obsolete in R, since the working directory tracks the current task. It is more important in the S+ version of mvbutils.

Author(s)

Mark Bravington

See Also

cd, getwd, file.path

Examples

## Not run: 
if( FALSE && is_very_annoying( CRAN)){ # otherwise CMD CHECK --as-cran tries to run this :/
  task.home( "myfile.c") # probably the same as file.path( getwd(), "myfile.c")
  task.home() # probably the same as getwd()
} # if F

## End(Not run)

mvbutils documentation built on May 25, 2026, 5:09 p.m.

Related to task.home in mvbutils...