| RENEWS | R Documentation |
Probably only for me. Each of my maintained packages has a <mypack>.NEWS object (character vector) in a pretty arbitrary format which I might as well markdownize, so that utils::news can process it. Reverse order (previously, most recent came last).) Remove dates.
RENEWS( pkg, character.only = FALSE)
pkg |
eg |
character.only |
for programmatic use, enforce string format as |
Modified <pkg>.NEWS of class cat, so you can check it before manually assiging to eg ..<mypack>$<mypack>.NEWS. Likely to need cleanup with fixr afterwards!
## Not run:
if( FALSE && is_very_annoying( CRAN)){ # otherwise CMD CHECK --as-cran tries to run this :/
RENEWS( mvbutils)
} # if F
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.