| cdprompt | R Documentation |
Sets the command-line prompt to the correct value (see cd, and the notes on the option abbreviate.cdprompt); useful if the prompt somehow becomes corrupted. cdprompt never seems necessary in R but has been useful in the S+ manifestations of mvbutils, where system bugs are commoner.
cdprompt()
Mark Bravington
cd
cdprompt()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.