| dedoc_namespace | R Documentation |
Suppose you want to keep plain-text "doc" attributes attached to your function code even in the package source (as opposed to in a private version of the package). You probably don't want them around after the package loads for real, though. In that case, you can stick a call to dedoc_namespace at the end of your .onLoad and everything should be copacetic.
dedoc_namespace(ns)
ns |
Name of the package, or its namespace environment. |
write_sourceable_function, pre.install
## Not run:
if( FALSE && is_very_annoying( CRAN)){ # otherwise CMD CHECK --as-cran tries to run this :/
# Put this into your package:
.onLoad <- function( libname, pkgname){
# stuff for .onLoad(), or no stuff
dedoc_package( pkgname)
}
} # if F
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.