| mvb.session.env | R Documentation |
Package mvbutils needs a place to stash useful session-level stuff, such as fix.list (see fixr). Since like foreeeever (2001), this has been via a special environment called mvb.session.info which is attached to the search path. However, that's not how yer sposed to do it apparently, so for better security the direct use of mvb.session.info is deprecated in favour of calling the function mvb_session_env() or its dotty synonym. Like the base-R functions globalenv() and baseenv(), an environment is returned.
Future versions of mvbutils package will move the session-info environment into "private" storage within the mvbutils namespace, so that it can only easily be accessed via mvb_session_env() or mvb.session.env().
mvb_session_env()
mvb.session.env()
Environment where session-level info used by the mvbutils package (and perhaps by other packages, such as debug) is stashed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.