| mvboption | R Documentation |
Set/get values in the environment mvbutils::mvboptions. Mostly for mvbutils itself, but anyone can use it at their own risk! Partly intended to ultimately obviate the dicey mvb.session.info environment on the search path...
mvboption(...) # eg mvboption( use_something=TRUE) to set,
# ... or mvboption( 'what_am_i') to get
... |
Either a named pairlist (eg |
Any previous value(s) of the options, if setting; this might mean an empty list. When getting, it's a list if more than one thing is being gotten, or the value itself if just one. More obvious than it sounds. See Examples.
mvboption( something=1) # empty list
mvboption( a=2, b=3) # empty list
mvboption( 'b') # [1] 3
mvboption( cq( a, b)) # list with two elements
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.