| screen_masked_imports | R Documentation |
Suppose your package imports various other packages. Despite the pious advice about only selectively importing certain functions, it's perfectly fine and very convenient to just be able to import(otherpack) in your NAMESPACE (or the equivalent, in whatever system you use to auto-generate the NAMESPACE). One annoyance, though, is that several packages may export different things with the same name, which leads to disconcerting warnings about "replacing import..." when your package is loaded. This can be circumvented in NAMEPACE using this syntax:
But you sure don't want to have to work out those NAMESPACE details yourself, so this function does it for you.
Mostly, this function will be called invisibly during make.NAMESPACE during pre.install, but you could try it yourself for more manual things.
screen_masked_imports( imports, myfuns)
imports |
names of packages that yours imports (or Depends on) |
myfuns |
functions in your package. You don't want to import other functions with the same name, because those imports will just be overridden. |
List of character vectors, one element per imports, saying which if any functions exported by that importee should not be imported via your NAMESPACE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.