| task.home | R Documentation |
Returns file path to current task, or to a file in that task.
# Often: task.home()
task.home(fname)
fname |
file name, a character(1) |
Without any arguments, task.home returns the path of the current task. With a filename argument, the filename is interpreted as relative to the current task, and its full (non-relative) path is returned.
task.home is almost obsolete in R, since the working directory tracks the current task. It is more important in the S+ version of mvbutils.
Mark Bravington
cd, getwd, file.path
## Not run:
if( FALSE && is_very_annoying( CRAN)){ # otherwise CMD CHECK --as-cran tries to run this :/
task.home( "myfile.c") # probably the same as file.path( getwd(), "myfile.c")
task.home() # probably the same as getwd()
} # if F
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.